act.plotting.GeographicPlotDisplay
==================================

.. currentmodule:: act.plotting

.. autoclass:: GeographicPlotDisplay

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~GeographicPlotDisplay.__init__
      ~GeographicPlotDisplay.add_colorbar
      ~GeographicPlotDisplay.add_subplots
      ~GeographicPlotDisplay.assign_to_figure_axis
      ~GeographicPlotDisplay.geoplot
      ~GeographicPlotDisplay.put_display_in_subplot
   
   

   
   
   